%% Import data
Data = readtable("CPET data fast ramp.xlsx");


%% Create Wasserman panel
fig1 = figure;
subplot(3,3,1);
plot(Data.V_E);
xlabel("Time");
ylabel("Ventilation");

subplot(3,3,2);
plot(Data.HR);
xlabel("Time");
ylabel("Heart rate [bpm]");

subplot(3,3,3);
plot(Data.V_O2),hold on;
plot(Data.V_CO2);
xlabel("Time");
legend(["VO2" "VCO2"],"Location","best","Box","off");

subplot(3,3,4);
plot(Data.V_CO2,Data.V_E,'.');
xlabel("VCO2");
ylabel("Ventilation");

subplot(3,3,5);
plot(Data.V_O2,Data.V_CO2,'.');
xlabel("VO2");
ylabel("VCO2");

subplot(3,3,6);
plot(Data.V_E_V_O2),hold on;
plot(Data.V_E_V_CO2);
xlabel("Time");
legend(["VE/VO2" "VE/VCO2"],"Location","best","Box","off");

subplot(3,3,7);
plot(Data.V_E,Data.VT,'.');
xlabel("Ventilation");
ylabel("Tidal volume");

subplot(3,3,8);
plot(Data.V_CO2./Data.V_O2);
xlabel("Time");
ylabel("RER");

saveas(fig1,"Wassermann.png");


%% Panel 6
figure,
plot(Data.V_E_V_O2),hold on;
plot(Data.V_E_V_CO2);
xlabel("Time");
legend(["VE/VO2" "VE/VCO2"],"Location","best","Box","off");


%% Panel 5
figure,
plot(Data.V_O2,Data.V_CO2,'.'),hold on;
plot(Data.V_O2(468),Data.V_CO2(468),'ro');
plot(Data.V_O2(608),Data.V_CO2(608),'ko');
xlabel("VO2");
ylabel("VCO2");


%% Panel 4
figure,
plot(Data.V_CO2,Data.V_E,'.'),hold on;
plot(Data.V_CO2(608),Data.V_E(608),'ro');
xlabel("VCO2");
ylabel("Ventilation");


%% Trend line
Ex = find(string(Data.Phase) == "Exercise",1);
Model_VT1 = fitlm(Data.V_O2(Ex:468),Data.V_CO2(Ex:468));
Vec_VT1 = linspace(Data.V_O2(Ex),Data.V_O2(468),468-Ex);
Pred_VT1 = predict(Model_VT1,Vec_VT1');

Model_VT2 = fitlm(Data.V_O2(469:608),Data.V_CO2(469:608));
Vec_VT2 = linspace(Data.V_O2(469),Data.V_O2(608),608-469);
Pred_VT2 = predict(Model_VT2,Vec_VT2');

[~,I] = max(Data.V_O2);
Model_Max = fitlm(Data.V_O2(609:I),Data.V_CO2(609:I));
Vec_Max = linspace(Data.V_O2(609),Data.V_O2(I),I-609);
Pred_Max = predict(Model_Max,Vec_Max');

fig2 = figure;
plot(Data.V_O2,Data.V_CO2,'.'),hold on;
plot(Data.V_O2(468),Data.V_CO2(468),'ro');
plot(Vec_VT1,Pred_VT1,'r-',"LineWidth",2);
plot(Data.V_O2(608),Data.V_CO2(608),'ko');
plot(Vec_VT2,Pred_VT2,'k-',"LineWidth",2);
plot(Data.V_O2(I),Data.V_CO2(I),'go');
plot(Vec_Max,Pred_Max,'g-',"LineWidth",2);
xlabel("VO2");
ylabel("VCO2");

saveas(fig2,"Trend line.png");


%% VO2 max
VO2_max = max(Data.V_O2)*1000/65;

Pred_C = (max(Data.WR)/65)*10.791+7;

Pred_wassermann = 50.72-(0.372*26);


%% HR max
HR_max = max(Data.HR);

HR_fox = 220-26;

HR_Tanaka = 208-(0.7*26);

HR_Nikolaidis = 223-(1.44*26);


%% HR in VT 1 and VT2
HR_VT1 = Data.HR(468);

HR_VT2 = Data.HR(608);






